@@ -2,6 +2,9 @@ import psycopg2
 import json
 
 class Postgres_Handler:
+    #Key for table_name string
+    table_name_key = 'table_name'
+    
     #Initializer that takes the values for connection
     def __init__(self, user_name, password, host, port, database):
         self.user_name = user_name
@@ -9,6 +12,7 @@ class Postgres_Handler:
         self.host = host
         self.port = port
         self.database = database
+        
    
     # Used internally create to run query
     def __run_query(self, query, values):
@@ -51,7 +55,7 @@ class Postgres_Handler:
 
         #Runs the query and returns the results
         results = self.__run_query(query_value_list[0], query_value_list[1])
-        payload = self.__format_search_results(results)
+        payload = self.__format_search_results(results, columns)
     
         return payload
 
@@ -140,8 +144,6 @@ class Postgres_Handler:
         
     #This needs to be looked at, likely there are only certain fields that will be passed and the rest will be created either in lambda or S3/postgresql
     def insert_row(self, **kwargs):
-        #Key to get table_name argument
-        table_name_key = 'table_name'
         
         #Values dictioniary for sql parameters
         values_dict = {}
@@ -151,13 +153,13 @@ class Postgres_Handler:
         column_values_string = ''
         
         #checks for the table name in args
-        if table_name_key not in kwargs:
+        if self.table_name_key not in kwargs:
             assert("Error: table_name required as argument")
-        table_name = kwargs[table_name_key]
+        table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
         query_start = 'INSERT INTO %(table_name)s'
-        values_dict[table_name_key] = table_name
+        values_dict[self.table_name_key] = table_name
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
         for key, value in kwargs.items():
@@ -173,9 +175,9 @@ class Postgres_Handler:
         
         #Runs the command
         results = self.__run_query(query, values_dict)
-        return self.__format_insert_results(results)
+        return self.__format_results(results)
         
-    def __format_insert_results(self, results):
+    def __format_results(self, results):
         internal_status = results[0]
         message = results[1]  if internal_status != -1 else ''
         error = results[1] if internal_status == -1  else ''
@@ -196,39 +198,49 @@ class Postgres_Handler:
         } 
         
     #Method to update a SQL row
-    def update_row(self, **kwargs):
+    def update_record(self, kwargs):
+        values_dict = {}
         id_key = 'id'
-        other_search_key = 'oldName'
+        clause_section = ''
         
-        query_string = 'UPDATE "MetaData" SET'
-        for key in kwargs:
-            if key == id_key or key not in self.metadata_column_map: continue
-            
-            column_name = self.metadata_column_map[key]
-            section = f' "{column_name}" = \'{kwargs[key]}\','
-            query_string += section
-            
-        query_string = query_string[:-1]
+         #checks for the table name in args
+        if self.table_name_key not in kwargs:
+            assert("Error: table_name required as argument")
+        table_name = kwargs[self.table_name_key]
         
-        if id_key in kwargs:
-            id_val = kwargs['id']
-            query_string += f' WHERE "ID"=\'{id_val}\''
-        else:
-            search_val = kwargs[other_search_key]
-            query_string += f' WHERE "FileName"=\'{search_val}\''
+        #Begining of the SQL query
+        query_start = 'UPDATE %(table_name)s SET'
+        values_dict[self.table_name_key] = table_name
+        
+        for key, value in kwargs.items():
+            if key.lower() == "id": continue
+            
+            clause_section = f' "{key}" = %({key})s,'
+            values_dict[key] = value
+        
+        query_string += clause_section[:-1]
+        
+        if id_key not in kwargs: assert("Error: ID of record required for an update!")
+        id_val = kwargs['id']
+        query_string += f' WHERE "ID"=\'{id_val}\''
         
         results = self.__run_query(query_string)
-        return results
+        return self.__format_results(results)
+    
+        
     
     #Delete command, will use policy or agent number to delete
     #todo - This may requrie removing items from S3 not sure yet how that will work
-    def deleteRow(self, number, status):
-        #Primary column to find row that should be removed
-        primary_column = f'{status.lower().title()}Number'
+    def deleteRow(self, **kwargs):
+        #key for table and id 
+        table_name_key = "table_name"
+        id_key = "ID"
+        
+        value_dict = {key: value for key, value in kwargs.items() if key.lower() == table_name_key.lower() or key.lower() == id_key.lower()}
         
         #Builds query to run 
-        query_string = f'DELETE FROM "MetaData" WHERE "{primary_column}"=\'{number}\''
+        query_string = 'DELETE FROM %(table_name)s WHERE ID = %(ID)s'
         
         #Runs the query and handles the success or error.
-        results = self.__run_query(query_string)
+        results = self.__run_query(query_string, value_dict)
         return results
